package gg.malloc.defense;

import org.bukkit.plugin.java.JavaPlugin;
import org.bukkit.plugin.RegisteredServiceProvider;
import org.bukkit.Location;
import org.bukkit.entity.Entity;
import org.bukkit.entity.EntityType;
import org.bukkit.World;
import org.bukkit.plugin.PluginLogger;

import java.util.ArrayList;
import java.util.HashMap;

import gg.malloc.defense.model.Arena;
import gg.malloc.defense.model.Spawnpoint;
import gg.malloc.defense.model.Game;

import gg.malloc.defense.games.LinearGame;

public class Plugin extends JavaPlugin {
  ArrayList<Arena> m_arenas = new ArrayList<>();
  ArrayList<Game> m_games = new ArrayList<>();
  HashMap<World, GameRunner> m_runningGames = new HashMap<>();

  private class TestSpawn implements Spawnpoint {
    Location m_location;

    public TestSpawn(Location location) {
      m_location = location;
    }

    @Override
    public Location getLocation() {
      return m_location;
    }

    @Override
    public String getName() {
      return "Mob Spawner";
    }

    @Override
    public String getID() {
      return "mob-spawner";
    }
  }

  PluginLogger m_log = new PluginLogger(this);

  public void debuginfo() {
    m_log.info("Debug Info:");
  }

  @Override
  public void onEnable() {
    getLogger().info("Malloc Defense registered");
    setupTestGame();
    getCommand("setstage").setExecutor(new SetStageCommand(this));
    getCommand("initgame").setExecutor(new InitGameCommand(this));
    getCommand("debuginfo").setExecutor(new DebuginfoCommand(this));
    getServer().getPluginManager().registerEvents(new GameEventHandler(this), this);
  }

  public GameRunner getRunnerForWorld(World world) {
    GameRunner ret;
    if (m_runningGames.containsKey(world)) {
      ret = m_runningGames.get(world);
    } else {
      ret = new GameRunner(this, m_games.get(0), m_arenas.get(0));
      m_runningGames.put(world, ret);
    }
    return ret;
  }

  void setupTestGame() {
    World testWorld = getServer().getWorld("world");
    Spawnpoint[] spawnpoints = new Spawnpoint[1];
    spawnpoints[0] = new TestSpawn(testWorld.getSpawnLocation());
    m_arenas.add(new MemoryArena("Test Arena", testWorld, spawnpoints));
    m_games.add(new LinearGame());
  }
}
